<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;
use Session;
use Storage;
use Carbon\Carbon;

use App\Category;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:category-list|category-create|category-edit|category-delete', ['only' => ['index','store']]);
         $this->middleware('permission:category-create', ['only' => ['create','store']]);
         $this->middleware('permission:category-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:category-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'description';
        $tm[0]['upload_url'] = 'categories';
        $tm[0]['field_height'] = '300';

        $this->tm = $tm;

        // Upload folder
        $this->folder = 'categories';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_categories');
        $route = route('categories.create');
        $pageType = 'index';
        $canCreate = 'category-create';
        $canExport = null;

        $categories = Category::categoryAll();

        return view('categories.index',compact('title','route','pageType','canCreate','canExport',
                                                        'categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_categories');
        $route = route('categories.index');
        $pageType = 'create';

        $tm = $this->tm;

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();
        $categoryDATA = array();

        return view('categories.create',compact('title','route','pageType','tm',
                                                    'categories_SEL','categoriesForAttribute','categoryDATA'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'name' => 'required',
            'slug' => 'required|unique:categories,slug'
        ]);
    
        $category = Category::create([
            'name' => $request->input('name'),
            'parent_id' => $request->input('parent_id'),
            'cat_order' => $request->input('cat_order'),
            'description' => $request->input('description'),
            'slug' => $request->input('slug'),
            'active' => $request->input('active'),
            'meta_description' => $request->input('meta_description'),
            'meta_keywords' => $request->input('meta_keywords')
        ]);

        // IMG upload
        if (null !== request('cat_image')):

            $file = $request->file('cat_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$category->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $category = Category::where('id',$category->id)
                                    ->update([
                                        'cat_image' => $imgNAME
                                    ]);
        endif;
    
        return redirect()->route('categories.index')
                        ->with('success','Category created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // page header
        $title = __('dashboard.title_categories');
        $route = route('categories.index');
        $pageType = 'show';

        $category = Category::find($id);
    
        return view('categories.show',compact('title','route','pageType',
                                                'category'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_categories');
        $route = route('categories.index');
        $pageType = 'edit';

        // TinyMCE
        $tm = $this->tm;

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();

        // Category
        $categoryDATA = Category::categoryByID($id);
    
        return view('categories.edit',compact('title','route','pageType','tm',
                                                        'categories_SEL','categoriesForAttribute',
                                                        'categoryDATA'));
    }

        /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {   

        $this->validate($request, [
            'name' => 'required',
            'slug' => 'required'
        ]);
    
        $category = Category::find($id);
        $category->name = $request->input('name');
        $category->parent_id = $request->input('parent_id');
        $category->cat_order = $request->input('cat_order');
        $category->description = $request->input('description');
        $category->slug = $request->input('slug');
        $category->active = $request->input('active');
        $category->meta_description = $request->input('meta_description');
        $category->meta_keywords = $request->input('meta_keywords');
        

        // IMG upload
        if (null !== request('cat_image')):

            $file = $request->file('cat_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$category->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);
           
            $category->cat_image = $imgNAME;
        endif;

        $category->save();
    
        return redirect()->route('categories.index')
                        ->with('success','Category updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("categories")->where('id',$id)->delete();
        return redirect()->route('categories.index')
                        ->with('success','Category deleted successfully');
    }
}
