<?php

namespace App\Http\Controllers;
use DB;
use Session;
use Storage;
use Carbon\Carbon;
use Auth;

use App\Post;
use App\Category;

use Illuminate\Http\Request;

class PostController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:post-list|post-create|post-edit|post-delete', ['only' => ['index','store']]);
         $this->middleware('permission:post-create', ['only' => ['create','store']]);
         $this->middleware('permission:post-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:post-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'excerpt';
        $tm[0]['upload_url'] = 'posts';
        $tm[0]['field_height'] = '300';

        $tm[1]['selector'] = 'body';
        $tm[1]['upload_url'] = 'posts';
        $tm[1]['field_height'] = '600';

        $this->tm = $tm;

        // Upload folder
        $this->folder = 'posts';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_posts');
        $route = route('posts.create');
        $pageType = 'index';
        $canCreate = 'post-create';
        $canExport = null;

        $posts = Post::paginate(10);

        return view('posts.index',compact('title','route','pageType','canCreate','canExport',
                                                        'posts'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_posts');
        $route = route('posts.index');
        $pageType = 'create';

        $tm = $this->tm;

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();
        $categoryDATA = array();

        return view('posts.create',compact('title','route','pageType','tm',
                                            'categories_SEL','categoriesForAttribute','categoryDATA'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $loggedIn = Auth::user();

        $this->validate($request, [
            'title' => 'required',
            'slug' => 'required|unique:posts,slug'
        ]);

        $post = Post::create([
            'author_id' => $loggedIn->id,
            'category_id' => $request->input('category_id'),
            'title' => $request->input('title'),
            'excerpt' => $request->input('excerpt'),
            'body' => $request->input('body'),
            'slug' => $request->input('slug'),
            'status' => $request->input('status'),
            'featured' => $request->input('featured'),
            'meta_description' => $request->input('meta_description'),
            'meta_keywords' => $request->input('meta_keywords')
        ]);

        // IMG upload
        if (null !== request('post_image')):

            $file = $request->file('post_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$post->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $post = Post::where('id',$post->id)
                                    ->update([
                                        'post_image' => $imgNAME
                                    ]);
        endif;
    
        return redirect()->route('posts.index')
                        ->with('success','Post created successfully');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // page header
        $title = __('dashboard.title_posts');
        $route = route('posts.index');
        $pageType = 'show';

        $post = Post::find($id);
    
        return view('posts.show',compact('title','route','pageType',
                                                'post'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_posts');
        $route = route('posts.index');
        $pageType = 'edit';

        // TinyMCE
        $tm = $this->tm;

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();
        $categoryDATA = new Category;

        $post = Post::find($id);
    
        return view('posts.edit',compact('title','route','pageType','tm',
                                            'categories_SEL','categoriesForAttribute','categoryDATA',
                                            'post'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {   

        $loggedIn = Auth::user();


        $this->validate($request, [
            'title' => 'required',
            'slug' => 'required'
        ]);
   
        $post = Post::find($id);
        $post->author_id = $loggedIn->id;
        $post->category_id = $request->input('category_id');
        $post->title = $request->input('title');
        $post->excerpt = $request->input('excerpt');
        $post->body = $request->input('body');
        $post->slug = $request->input('slug');
        $post->status = $request->input('status');
        $post->featured = $request->input('featured');
        $post->meta_description = $request->input('meta_description');
        $post->meta_keywords = $request->input('meta_keywords');
        

        // IMG upload
        if (null !== request('post_image')):

            $file = $request->file('post_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$post->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);
           
            $post->post_image = $imgNAME;
        endif;

        $post->save();
    
        return redirect()->route('posts.index')
                        ->with('success','Post updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("posts")->where('id',$id)->delete();

        return redirect()->route('posts.index')
                        ->with('success','Post deleted successfully');
    }
}
