<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

use URL;
use DB;

class Page extends Model
{
    protected $primaryKey = 'id';
    protected $table = 'pages';

    /**
     * The attributes that are mass assignable.
     *	
     * @var array
     */
    protected $fillable = [
        'author_id', 'title', 'slug', 'excerpt', 'body', 'page_image', 'status', 'meta_description', 'meta_keywords'
    ];

    public static function pagesAll()
    {

        $pages = DB::table('pages as p')
                            ->join('users as u','u.id','p.author_id')
                            ->select(
                               'p.id as id',
                               'p.author_id as author_id',
                               'u.name as author_name',
                               'u.last_name as author_last_name',
                               'p.title as title',
                               'p.slug as slug',
                               'p.excerpt as excerpt',
                               'p.body as body',
                               'p.page_image as page_image',
                               'p.status as status',
                               'p.meta_description as meta_description',
                               'p.meta_keywords as meta_keywords'
                            )
                            ->orderBy('p.created_at','DESC')
                            ->paginate(10);
       
        return $pages;
    }

    public static function pagesByID($pageID)
    {

        $page = DB::table('pages as p')
                            ->join('users as u','u.id','p.author_id')
                            ->where('p.id',$pageID)
                            ->select(
                               'p.id as id',
                               'p.author_id as author_id',
                               'u.name as author_name',
                               'u.last_name as author_last_name',
                               'p.title as title',
                               'p.slug as slug',
                               'p.excerpt as excerpt',
                               'p.body as body',
                               'p.page_image as page_image',
                               'p.status as status',
                               'p.meta_description as meta_description',
                               'p.meta_keywords as meta_keywords'
                            )
                            ->first();
       
        return $page;
    }

    // relatioships
    public function user()
    {
        return $this->hasOne('App\User','id','author_id');
    }
}
